#
# spec file for package ebiso
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ebiso
Version:        0.2.5
Release:        13.29
Summary:        UEFI bootable ISO image creator for Relax-and-Recover
License:        GPL-2.0+
Group:          Productivity/Archiving/Backup
# Refer to http://license.opensuse.org/
# for the list of known licences and their exact spelling:
# ebiso is only used by rear to make UEFI bootable ISO images
# accordingly ebiso is in the same RPM group as rear:
Url:            https://github.com/gozora/ebiso
Source0:        https://github.com/gozora/ebiso/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# Supplements is a reverse "Recommends" which means
# (cf. https://tr.opensuse.org/Libzypp/Dependencies):
# ebiso should be be installed if rear is is provided by an installed package.
# In particular ebiso should be be installed if rear is (to be) installed.
# The dependency resolver will do a best-try approach to install ebiso.
# If ebiso cannot be installed, installing ebiso is silently skipped.
# Also uninstalling ebiso is (silently) accepted.
# The reverse "Recommends" is used because ebiso is only available on x86_64
# so that a "Recommends: ebiso" in rear.spec could be often uninstallable.
# In contrast "Supplements: rear" in ebiso.spec can be usually fulfilled:
Supplements:    rear
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# Enable building only on architectures which support UEFI
ExclusiveArch:  %ix86 x86_64 aarch64

%description
ebiso is needed by Relax-and-Recover (abbreviated ReaR)
to create bootable ISO images with enabled UEFI boot
on 64-bit x86_64 architecture.

ebiso only works for systems with UEFI boot.
ebiso cannot create legacy bootable ISOs.

See project pages at https://github.com/gozora/ebiso

%prep
%setup -q

%build
# Setting our preferred architecture-specific flags for the compiler and linker:
export CFLAGS="%{optflags}"
# Do not strip installed binaries as this would prevent -debuginfo package
# from being created
sed -i "s|strip|/bin/true|g" Makefile
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install

%files
%defattr(-,root,root)
%{_bindir}/ebiso
%{_mandir}/man1/ebiso.1%{ext_man}

%changelog
* Wed Mar  1 2017 jsmeix@suse.de
- Bugfix update to version 0.2.5:
  * Fixed segfault with XFS ftype=0, see
    https://github.com/gozora/ebiso/issues/9
    and the actual root cause in ReaR
    https://github.com/rear/rear/issues/1208
* Sun Aug 28 2016 mpluskal@suse.com
- Update to version 0.2.4:
  * Debian related package scripts added.
- Use url for source.
- Enable parallel building and installation.
- Enable building on all platform that support UEFI.
- Use macro for manpage extension.
- Do not strip installed binaries, this prevents debuginfo packages
  from being built.
* Wed Apr 13 2016 jsmeix@suse.de
- New package ebiso for SUSE Linux Enterprise (fate#319332).
  ebiso is needed as helper tool by rear since rear version 1.18
  for making a UEFI bootable rear recovery system ISO image
  (see also bsc#931824).
* Fri Apr  8 2016 jsmeix@suse.de
- Bugfix update to version 0.2.3.1 see upstream issue
  https://github.com/gozora/ebiso/issues/7
  Now upstream Makefile accepts CFLAGS from environment
  so that setting our preferred flags for the compiler
  and linker via
    export CFLAGS="$RPM_OPT_FLAGS"
  does now work.
* Thu Apr  7 2016 jsmeix@suse.de
- Bugfix update to version 0.2.3 see upstream issue
  https://github.com/gozora/ebiso/issues/6 and
  https://github.com/gozora/ebiso/releases/tag/v0.2.3
  (boo#974360).
- Setting our preferred flags for the compiler and linker via
    export CFLAGS="$RPM_OPT_FLAGS"
  does not work because upstream Makefile uses FLAGS instead
  of CFLAGS so that the upstream FLAGS are overridden with
  our preferred flags added to the upstream FLAGS (boo#974360).
* Mon Apr  4 2016 jsmeix@suse.de
- Bugfix update to version 0.2.2
  In certain cases ebiso will overwrite one "random" byte
  with '\0', which might lead to file corruption, see
  https://github.com/gozora/ebiso/releases/tag/v0.2.2
  See also the following description by the ebiso author
  Vladimir Gozora in a mail from him (excerpts):
  "... captious bug in ebiso, that can cause (under certain
    circumstances) corruption of random file by overwriting
    one byte with zero ('\0'). This overwrite always happens
    on the end of block of 2048 bytes so for this reason it
    can remain unnoticed most of the time. ... In general
    ISO should be safe once user is able to boot from it."
* Wed Mar 23 2016 jsmeix@suse.de
- Added "Supplements: rear" in ebiso.spec so that ebiso gets
  usually installed if rear is (to be) installed (but ebiso
  is not strictly required by rear).
* Tue Mar 22 2016 jsmeix@suse.de
- Adapted spec file for openSUSE and SLE.
- Split RPM changelog into separate changes file.
* Sun Dec 13 2015 c@gozora.sk
- 0.2.1 release
  * Full symbolic link support
* Tue Oct 27 2015 c@gozora.sk
- 0.1.4 release
  * Added man page
* Wed Oct 21 2015 gratien.dhaese@gmail.com
- 0.1.1 release
  * Rewrote original spec file from Vladimir
